<?php

namespace Drupal\synhelper\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\Yaml\Yaml;

/**
 * Controller routines for page routes.
 */
class PageHome extends ControllerBase {

  /**
   * Page Title.
   */
  public function title($lang = FALSE) {
    if (!$lang) {
      $lang = \Drupal::languageManager()->getCurrentLanguage()->getId();
    }
    $titles = [
      'en' => $this->t('Home page'),
      'ru' => $this->t('Главная страница'),
    ];
    if (isset($titles[$lang])) {
      $title = $titles[$lang];
    }
    else {
      $title = $titles['en'];
    }
    return $title;
  }

  /**
   * Constructs page from template.
   */
  public function page($lang = FALSE) {
    $config = \Drupal::config('synhelper.settings');
    if (!$lang) {
      $lang = \Drupal::languageManager()->getCurrentLanguage()->getId();
    }
    $path = \Drupal::service('module_handler')->getModule('synhelper')->getPath();
    $templates = [
      'en' => DRUPAL_ROOT . "/$path/content/home-page-en.yml",
      'ru' => DRUPAL_ROOT . "/$path/content/home-page-ru.yml",
    ];
    if (isset($templates[$lang])) {
      $page = $templates[$lang];
    }
    else {
      $page = $templates['en'];
    }
    $html = '';
    if ($config->get('style-page')) {
      $array = Yaml::parse(file_get_contents($page));
      $html = $array['body'];
    }
    return [
      'home-page' => [
        '#type' => 'inline_template',
        '#template' => $html,
        '#context' => [
          'url' => $host = \Drupal::request()->getHost(),
        ],
      ],
    ];
  }

}
